DynamicAppIconFlutterPlus class

Constructors

DynamicAppIconFlutterPlus()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

supportsAlternateIcons → Future<bool>
Indicates whether the current platform supports dynamic app icons
no setter

Static Methods

applyPendingIcon() → Future<void>
Android-only: immediately apply the pending icon (if any) queued by setAlternateIconName.
getAlternateIconName() → Future<String?>
Fetches the current iconName
getAvailableIcons() → Future<List<String>>
Gets a list of all available alternate icon names
setAlternateIconName(String? iconName, {bool showAlert = true, bool deferUntilBackground = false}) → Future
Sets iconName as the current icon for the app